/**
  * Copyright (c): Uwe Schmidt, FH Wedel
  *
  * You may study, modify and distribute this source code
  * FOR NON-COMMERCIAL PURPOSES ONLY.
  * This copyright message has to remain unchanged.
  *
  * Note that this document is provided 'as is',
  * WITHOUT WARRANTY of any kind either expressed or implied.
  */
/**
  * The original sourcecode was modified to 
  * fit the phonebook requirements.
  * This sourcefile only contains the required 
  * functionality for the xml-example. For 
  * binary-tree-implementation, please check the
  * original sourcecode.
  * This file may contain some additional functions.
  * 
  * @author: Sascha Wille (inf6201@fh-wedel.de)
  */

#include "entry.h"

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <assert.h>

/**
 * compares two entries
 *
 * @param[in] entry1
 * @param[in] entry2
 *
 * @return 0 = equal
 *        -1 = e1 <  e2
 *         1 = e2 >= e2
 */
int compare(Entry e1, Entry e2) {
    /* sorted by name so first compare the name */
    int rel = strcmp(e1->name, e2->name);
    if (rel == 0)
        rel = strcmp(e1->phone, e2->phone);

    return rel == 0
            ? 0
            : rel > 0
            ? 1
            : -1;
}

/**
 * compares the phonenumbers of two entries
 *
 * @param[in] phonenumber
 * @param[in] entry 2
 *
 * @return 0 = equal
 *        -1 = no <  e->no
 *         1 = no >= e->no
 */
extern
int comparePhoneNo(char * no, Entry e) {
    int rel = strcmp(no, e->phone);
    return rel == 0
            ? 0
            : rel > 0
            ? 1
            : -1;
}

/**
 * creates an empty entry
 *
 * @return empty entry
 */
Entry mkEmptyEntry() {
    return (Entry) 0;
}

/**
 * creates an specific entry
 *
 * @param[in] surname of entry
 * @param[in] firstname of entry
 * @param[in] phonenumber of entry
 *
 * @return new entry
 */
Entry mkEntry(char *surname, char *firstname, char *phone, unsigned int mobile) {
    Entry res = malloc(sizeof (*res));
    if (!res)
        exit(1);
    res->firstname = firstname;
    res->name = surname;
    res->phone = phone;
    res->mobile = mobile;

    return res;
}

/**
 * formatted entry printout
 *
 * @param[in] entry to be printed
 */
void printEntry(Entry e) {
    fprintf(stdout,"\n------------------------\nName      : %s\n"
                   "Firstname : %s\nPhone     : %s\nMobile    : %s\n------------------------\n"
                  , e->name, (e->firstname == NULL) ? "-" : e->firstname, e->phone, (e->mobile) ? "yes" : "no");
}
