/**
  * Copyright (c): Uwe Schmidt, FH Wedel
  *
  * You may study, modify and distribute this source code
  * FOR NON-COMMERCIAL PURPOSES ONLY.
  * This copyright message has to remain unchanged.
  *
  * Note that this document is provided 'as is',
  * WITHOUT WARRANTY of any kind either expressed or implied.
  */
/**
  * The original sourcecode was modified to 
  * fit the phonebook requirements.
  * This sourcefile only contains the required 
  * functionality for the xml-example. For 
  * binary-tree-implementation, please check the
  * original sourcecode.
  * This file may contain some additional functions.
  * 
  * @author: Sascha Wille (inf6201@fh-wedel.de)
  */

#ifndef Entry_H__
#define Entry_H__

typedef struct Element *Entry;

struct Element {
    char *name;
    char *firstname;
    char *phone;
    unsigned int mobile;
};

/**
 * compares two entries
 * 
 * @param[in] entry1
 * @param[in] entry2
 *
 * @return 0 = equal
 *        -1 = e1 <  e2
 *         1 = e2 >= e2
 */
extern
int compare(Entry e1, Entry e2);

/**
 * compares the phonenumbers of two entries
 *
 * @param[in] phonenumber
 * @param[in] entry 2
 *
 * @return 0 = equal
 *        -1 = no <  e->no
 *         1 = no >= e->no
 */
extern
int comparePhoneNo(char * no, Entry e);

/**
 * creates an empty entry
 *
 * @return empty entry
 */
extern
Entry mkEmptyEntry();


/**
 * formatted entry printout
 *
 * @param[in] entry to be printed
 */
extern
void printEntry(Entry e);

/**
 * creates an specific entry
 *
 * @param[in] surname of entry
 * @param[in] firstname of entry
 * @param[in] phonenumber of entry
 *
 * @return new entry
 */
extern
Entry mkEntry(char *surname, char *firstname, char *phone, unsigned int mobile);

#endif
